@@ -131,13 +131,10 @@ impl BanksServer {
     }
 }
 
-fn verify_transaction(
-    transaction: &Transaction,
-    libsecp256k1_0_5_upgrade_enabled: bool,
-) -> transaction::Result<()> {
+fn verify_transaction(transaction: &Transaction) -> transaction::Result<()> {
     if let Err(err) = transaction.verify() {
         Err(err)
-    } else if let Err(err) = transaction.verify_precompiles(libsecp256k1_0_5_upgrade_enabled) {
+    } else if let Err(err) = transaction.verify_precompiles() {
         Err(err)
     } else {
         Ok(())
@@ -218,10 +215,7 @@ impl Banks for BanksServer {
         transaction: Transaction,
         commitment: CommitmentLevel,
     ) -> Option<transaction::Result<()>> {
-        if let Err(err) = verify_transaction(
-            &transaction,
-            self.bank(commitment).libsecp256k1_0_5_upgrade_enabled(),
-        ) {
+        if let Err(err) = verify_transaction(&transaction) {
             return Some(Err(err));
         }
 
